.. elicit documentation master file.

Welcome to elicit's documentation!
==================================

This is a library for simple, console based user input and output. It's goal is
to provide a nicer CLI experience for an application without requiring any
modules other than the standard library and the modules found here.


It also provides an enhanced debugger using this library for the command
interface.


.. toctree::
   :maxdepth: 2
   :caption: Contents:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
